/**
*   Nombre del Programa: Caminante
*   Proyecto: Aplicacin Android de Asistencia al Caminante
*   Uso: ayuda a pacientes con enfermedad de Parkinson 
*   	que presentan problemas de movilidad.
*   Acciones: Marcha, Anti Bloqueo y Anti Cada.
*   Medios: emisin de sonidos
**/    
/**    
    Copyright (C) 2011 Enrique Ramn Delgado Garrido

    This program is free software: you can redistribute it and/or modify 
    it under the terms of the GNU General Public License as published by 
    the Free Software Foundation, either version 3 of the License, or 
    (at your option) any later version. 

    This program is distributed in the hope that it will be useful, 
    but WITHOUT ANY WARRANTY; without even the implied warranty of 
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
    GNU General Public License for more details. 

    You should have received a copy of the GNU General Public License 
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/

package com.caminante.paquete;

import com.caminante.paquete.R;

import android.app.Dialog;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ToggleButton;
import android.content.Context;

public class MyDialogBloqueo extends Dialog {

	public interface ReadyListener {
		public void ready(
			float	numGravedad,
			float	numModulo,
			int		numEvento,
			float	numBloqueoT,
			boolean	booAccionBloqueo);
	}
	private	float	minGravedad	=	(float) 9.7524;
	private	float	minModulo	=	1;
	private	int		minEvento 	= 	10;
	private	float	minBloqueoT =	(float) 0.5;
	private	float	numGravedad	=	0;
	private	float	numModulo	=	0;
	private	int		numEvento 	= 	0;
	private	float	numBloqueoT =	0;
	private	float	maxGravedad	=	(float) 9.8322;
	private	float	maxModulo	=	15;
	private	int		maxEvento 	= 	200;
	private	float	maxBloqueoT =	(float) 6.0;
	private boolean	booAccionBloqueo = false;

	private ReadyListener 		readyListener;

	public MyDialogBloqueo(Context 		 context, 
						   float		 numGravedad,
						   float		 numModulo,
						   int			 numEvento,
						   float		 numBloqueoT,
						   boolean		 booAccionBloqueo,
						   ReadyListener readyListener)
	{
		super(context);
		this.numGravedad		= numGravedad;
		this.numModulo			= numModulo;
		this.numEvento			= numEvento;
		this.numBloqueoT		= numBloqueoT;
		this.booAccionBloqueo	= booAccionBloqueo;
		this.readyListener 		= readyListener;
	}	

	private Button		okButton;
	private Button		cancelButton;

	private Button		buttonGravedadMas;
	private Button		buttonGravedadMenos;
	private Button		buttonModuloMas;
	private Button		buttonModuloMenos;
	private Button		buttonEventoMas;
	private Button		buttonEventoMenos;
	private Button		buttonBloqueoTMas;
	private Button		buttonBloqueoTMenos;
	private Button		buttonAccionBloqueoMas;
	private Button		buttonAccionBloqueoMenos;
	
	private EditText	editTextGravedadNum;
	private EditText	editTextModuloNum;
	private EditText	editTextEventoNum;
	private EditText	editTextBloqueoTNum;

	private ToggleButton	tbuttonAccionBloqueo;	

	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setContentView(R.layout.maindialogbloqueo);
		
		okButton 			= (Button) findViewById(R.id.okButton);
		cancelButton 		= (Button) findViewById(R.id.cancelButton);

		buttonGravedadMas   		= (Button) findViewById(R.id.buttonGravedadMas);
		buttonGravedadMenos 		= (Button) findViewById(R.id.buttonGravedadMenos);
		buttonModuloMas    			= (Button) findViewById(R.id.buttonModuloMas);
		buttonModuloMenos  			= (Button) findViewById(R.id.buttonModuloMenos);
		buttonEventoMas   			= (Button) findViewById(R.id.buttonEventoMas);
		buttonEventoMenos 			= (Button) findViewById(R.id.buttonEventoMenos);
		buttonBloqueoTMas   		= (Button) findViewById(R.id.buttonBloqueoTMas);
		buttonBloqueoTMenos 		= (Button) findViewById(R.id.buttonBloqueoTMenos);
		buttonAccionBloqueoMas   	= (Button) findViewById(R.id.buttonAccionBloqueoMas);
		buttonAccionBloqueoMenos 	= (Button) findViewById(R.id.buttonAccionBloqueoMenos);

		editTextGravedadNum = (EditText) findViewById(R.id.editTextGravedadNum);
		editTextModuloNum  	= (EditText) findViewById(R.id.editTextModuloNum);
		editTextEventoNum 	= (EditText) findViewById(R.id.editTextEventoNum);
		editTextBloqueoTNum = (EditText) findViewById(R.id.editTextBloqueoTNum);

		tbuttonAccionBloqueo = (ToggleButton) findViewById(R.id.tbuttonAccionBloqueo);
		
		okButton.setOnClickListener(new OKListener());
		cancelButton.setOnClickListener(new OKListener());

		buttonGravedadMas.setOnClickListener(new OKListener());
		buttonGravedadMenos.setOnClickListener(new OKListener());
		buttonModuloMas.setOnClickListener(new OKListener());
		buttonModuloMenos.setOnClickListener(new OKListener());
		buttonEventoMas.setOnClickListener(new OKListener());
		buttonEventoMenos.setOnClickListener(new OKListener());
		buttonBloqueoTMas.setOnClickListener(new OKListener());
		buttonBloqueoTMenos.setOnClickListener(new OKListener());
		buttonAccionBloqueoMas.setOnClickListener(new OKListener());
		buttonAccionBloqueoMenos.setOnClickListener(new OKListener());
		
		editTextGravedadNum.setText("" + numGravedad);
		editTextGravedadNum.setInputType(0);
		editTextModuloNum.setText("" + numModulo);
		editTextModuloNum.setInputType(0);
		editTextEventoNum.setText("" + numEvento);
		editTextEventoNum.setInputType(0);
		editTextBloqueoTNum.setText("" + numBloqueoT);
		editTextBloqueoTNum.setInputType(0);
		
		tbuttonAccionBloqueo.setOnClickListener(new OKListener());
		tbuttonAccionBloqueo.setChecked(booAccionBloqueo);
		
		buttonAccionBloqueoMas.setEnabled(false);
		buttonAccionBloqueoMenos.setEnabled(false);
	}
	
	private class OKListener implements android.view.View.OnClickListener {
		//@Override	
		public void onClick(View view) {
			switch (view.getId()) {
				case R.id.buttonGravedadMas:
					if (numGravedad < maxGravedad) numGravedad = (float) (numGravedad + 0.01);      //++numGravedad;
					editTextGravedadNum.setText("" + numGravedad);
					break;
				case R.id.buttonGravedadMenos:
					if (numGravedad > minGravedad)  numGravedad = (float) (numGravedad - 0.01);      //--numGravedad;	
					editTextGravedadNum.setText("" + numGravedad);
					break;
				case R.id.buttonModuloMas:
					if (numModulo < maxModulo) ++numModulo;
					editTextModuloNum.setText("" + numModulo);
					break;
				case R.id.buttonModuloMenos:
					if (numModulo > minModulo) --numModulo;	
					editTextModuloNum.setText("" + numModulo);
					break;
				case R.id.buttonEventoMas:
					if (numEvento < maxEvento) ++numEvento;
					editTextEventoNum.setText("" + numEvento);
					break;
				case R.id.buttonEventoMenos:
					if (numEvento > minEvento) --numEvento;	
					editTextEventoNum.setText("" + numEvento);
					break;
				case R.id.buttonBloqueoTMas:
					if (numBloqueoT < maxBloqueoT) numBloqueoT = (float) (numBloqueoT + 0.5); 		//++numBloqueoT;
					editTextBloqueoTNum.setText("" + numBloqueoT);
					break;
				case R.id.buttonBloqueoTMenos:
					if (numBloqueoT > minBloqueoT) numBloqueoT = (float) (numBloqueoT - 0.5); 		//--numBloqueoT;	
					editTextBloqueoTNum.setText("" + numBloqueoT);
					break;
				case R.id.tbuttonAccionBloqueo:
					if (((ToggleButton)view).isChecked()) {
						booAccionBloqueo = true;
					} else {
						booAccionBloqueo = false;
					}
		            break;
				case R.id.okButton:
					readyListener.ready(numGravedad, numModulo, numEvento, numBloqueoT, booAccionBloqueo);
					MyDialogBloqueo.this.dismiss();
					break;
				case R.id.cancelButton:
					MyDialogBloqueo.this.cancel();
					break;
			}
		}
	}
}

