/**
*   Nombre del Programa: Caminante
*   Proyecto: Aplicacin Android de Asistencia al Caminante
*   Uso: ayuda a pacientes con enfermedad de Parkinson 
*   	que presentan problemas de movilidad.
*   Acciones: Marcha, Anti Bloqueo y Anti Cada.
*   Medios: emisin de sonidos
**/    
/**    
    Copyright (C) 2011 Enrique Ramn Delgado Garrido

    This program is free software: you can redistribute it and/or modify 
    it under the terms of the GNU General Public License as published by 
    the Free Software Foundation, either version 3 of the License, or 
    (at your option) any later version. 

    This program is distributed in the hope that it will be useful, 
    but WITHOUT ANY WARRANTY; without even the implied warranty of 
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
    GNU General Public License for more details. 

    You should have received a copy of the GNU General Public License 
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/

package com.caminante.paquete;

import com.caminante.paquete.R;

import android.app.Dialog;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.content.Context;

public class MyDialogCaida extends Dialog {

	public interface ReadyListener {
		public void ready(
			int		numEventoCaida,
			float	numPendienteCaida);
	}
	
	private Button	okButton;
	private Button	cancelButton;

	private	int		numEventoCaida 	= 	0;
	private	int		minEventoCaida 	= 	1;
	private	int		maxEventoCaida 	= 	20;

	private	float	numPendienteCaida 	= 	(float) 0.0;
	private	float	minPendienteCaida 	= 	(float) 0.5;
	private	float	maxPendienteCaida 	= 	(float) 2.0;

	private ReadyListener 		readyListener;

	public MyDialogCaida(Context context, int numEventoCaida, float numPendienteCaida, ReadyListener readyListener)
	{
		super(context);
		this.numEventoCaida		= numEventoCaida;
		this.numPendienteCaida	= numPendienteCaida;
		this.readyListener 		= readyListener;
	}	

	private Button			buttonEventoMas;
	private Button			buttonEventoMenos;

	private EditText		editTextEventoNum;

	private Button			buttonPendienteMas;
	private Button			buttonPendienteMenos;

	private EditText		editTextPendienteNum;

	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setContentView(R.layout.maindialogcaida);
		
		okButton 			= (Button) findViewById(R.id.okButton);
		cancelButton 		= (Button) findViewById(R.id.cancelButton);

		okButton.setOnClickListener(new OKListener());
		cancelButton.setOnClickListener(new OKListener());

		buttonEventoMas   	= (Button) findViewById(R.id.buttonEventoMas);
		buttonEventoMenos 	= (Button) findViewById(R.id.buttonEventoMenos);

		editTextEventoNum 	= (EditText) findViewById(R.id.editTextEventoNum);

		buttonEventoMas.setOnClickListener(new OKListener());
		buttonEventoMenos.setOnClickListener(new OKListener());

		editTextEventoNum.setText("" + numEventoCaida);
		editTextEventoNum.setInputType(0);

		buttonPendienteMas   	= (Button) findViewById(R.id.buttonPendienteMas);
		buttonPendienteMenos 	= (Button) findViewById(R.id.buttonPendienteMenos);

		editTextPendienteNum 	= (EditText) findViewById(R.id.editTextPendienteNum);

		buttonPendienteMas.setOnClickListener(new OKListener());
		buttonPendienteMenos.setOnClickListener(new OKListener());

		editTextPendienteNum.setText("" + numPendienteCaida);
		editTextPendienteNum.setInputType(0);
	}
	
	private class OKListener implements android.view.View.OnClickListener {
		//@Override	
		public void onClick(View view) {
			switch (view.getId()) {
				case R.id.buttonEventoMas:
					if (numEventoCaida < maxEventoCaida) ++numEventoCaida;
					editTextEventoNum.setText("" + numEventoCaida);
					break;
				case R.id.buttonEventoMenos:
					if (numEventoCaida > minEventoCaida) --numEventoCaida;	
					editTextEventoNum.setText("" + numEventoCaida);
					break;
				case R.id.buttonPendienteMas:
					if (numPendienteCaida < maxPendienteCaida) numPendienteCaida = (float) (numPendienteCaida + 0.1);
					editTextPendienteNum.setText("" + numPendienteCaida);
					break;
				case R.id.buttonPendienteMenos:
					if (numPendienteCaida > minPendienteCaida) numPendienteCaida = (float) (numPendienteCaida - 0.1);	
					editTextPendienteNum.setText("" + numPendienteCaida);
					break;
				case R.id.okButton:
					readyListener.ready(numEventoCaida, numPendienteCaida);
					MyDialogCaida.this.dismiss();
					break;
				case R.id.cancelButton:
					MyDialogCaida.this.cancel();
					break;
			}
		}
	}
}

