/**
*   Nombre del Programa: Caminante
*   Proyecto: Aplicacin Android de Asistencia al Caminante
*   Uso: ayuda a pacientes con enfermedad de Parkinson 
*   	que presentan problemas de movilidad.
*   Acciones: Marcha, Anti Bloqueo y Anti Cada.
*   Medios: emisin de sonidos
**/    
/**    
    Copyright (C) 2011 Enrique Ramn Delgado Garrido

    This program is free software: you can redistribute it and/or modify 
    it under the terms of the GNU General Public License as published by 
    the Free Software Foundation, either version 3 of the License, or 
    (at your option) any later version. 

    This program is distributed in the hope that it will be useful, 
    but WITHOUT ANY WARRANTY; without even the implied warranty of 
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
    GNU General Public License for more details. 

    You should have received a copy of the GNU General Public License 
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/

package com.caminante.paquete;

import com.caminante.paquete.R;

import android.app.Dialog;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.content.Context;

public class MyDialogMetronomo extends Dialog {

	public interface ReadyListener {
		public void ready(
				int	numPeriod,
				int	numTempo);
	}
	
	private	int					numPeriod	=  	0;
	private	int					numTempo	=	0;
	private static final int 	maxPeriod 	= 	8;
	private static final int 	maxTempo 	= 	200;

	private ReadyListener 		readyListener;

	public MyDialogMetronomo(Context context, 
							 int numPeriod,
							 int numTempo,
							 ReadyListener readyListener)
	{
		super(context);
		this.numPeriod 		= numPeriod;
		this.numTempo		= numTempo;
		this.readyListener 	= readyListener;
	}	

	private Button			okButton;
	private Button			cancelButton;

	private Button			buttonPeriodMas;
	private Button			buttonPeriodMenos;
	private Button			buttonTempoMas;
	private Button			buttonTempoMenos;

	private EditText		editTextPeriodNum;
	private EditText		editTextTempoNum;
	
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		setContentView(R.layout.maindialogmetronomo);
		
		okButton 			= (Button) findViewById(R.id.okButton);
		cancelButton 		= (Button) findViewById(R.id.cancelButton);

		buttonPeriodMas   	= (Button) findViewById(R.id.buttonPeriodMas);
		buttonPeriodMenos 	= (Button) findViewById(R.id.buttonPeriodMenos);
		buttonTempoMas    	= (Button) findViewById(R.id.buttonTempoMas);
		buttonTempoMenos  	= (Button) findViewById(R.id.buttonTempoMenos);

		editTextPeriodNum 	= (EditText) findViewById(R.id.editTextPeriodNum);
		editTextTempoNum  	= (EditText) findViewById(R.id.editTextTempoNum);

		okButton.setOnClickListener(new OKListener());
		cancelButton.setOnClickListener(new OKListener());

		buttonPeriodMas.setOnClickListener(new OKListener());
		buttonPeriodMenos.setOnClickListener(new OKListener());
		buttonTempoMas.setOnClickListener(new OKListener());
		buttonTempoMenos.setOnClickListener(new OKListener());
		
		editTextPeriodNum.setText("" + numPeriod);
		editTextPeriodNum.setInputType(0);
		editTextTempoNum.setText("" + numTempo);
		editTextTempoNum.setInputType(0);
	}
	
	private class OKListener implements android.view.View.OnClickListener {
		//@Override	
		public void onClick(View view) {
			switch (view.getId()) {
				case R.id.buttonPeriodMas:
					if (numPeriod < maxPeriod) ++numPeriod;
					editTextPeriodNum.setText("" + numPeriod);
					break;
				case R.id.buttonPeriodMenos:
					if (numPeriod > 1) --numPeriod;	
					editTextPeriodNum.setText("" + numPeriod);
					break;
				case R.id.buttonTempoMas:
					if (numTempo < maxTempo) ++numTempo;
					editTextTempoNum.setText("" + numTempo);
					break;
				case R.id.buttonTempoMenos:
					if (numTempo > 1) --numTempo;	
					editTextTempoNum.setText("" + numTempo);
					break;
				case R.id.okButton:
					readyListener.ready(numPeriod, numTempo);
					MyDialogMetronomo.this.dismiss();
					break;
				case R.id.cancelButton:
					//readyListener.ready(numPeriod, numTempo);
					MyDialogMetronomo.this.cancel();
					break;
			}
		}
	}
}

