/**
*   Nombre del Programa: Caminante
*   Proyecto: Aplicacin Android de Asistencia al Caminante
*   Uso: ayuda a pacientes con enfermedad de Parkinson 
*   	que presentan problemas de movilidad.
*   Acciones: Marcha, Anti Bloqueo y Anti Cada.
*   Medios: emisin de sonidos
**/    
/**    
    Copyright (C) 2011 Enrique Ramn Delgado Garrido

    This program is free software: you can redistribute it and/or modify 
    it under the terms of the GNU General Public License as published by 
    the Free Software Foundation, either version 3 of the License, or 
    (at your option) any later version. 

    This program is distributed in the hope that it will be useful, 
    but WITHOUT ANY WARRANTY; without even the implied warranty of 
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
    GNU General Public License for more details. 

    You should have received a copy of the GNU General Public License 
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/

package com.caminante.paquete;

import java.util.List;

import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.IBinder;
import android.util.Log;

public class SensorsService extends Service implements SensorEventListener {
	
	private	SensorManager		sensorManager;
	private Sensor 				acelerometro;
	private Sensor 				orientacion; 

	private boolean				runningBloqueo = false;
	private boolean				runningCaida   = false;
	private boolean				runningType[]  = new boolean[2];
					
	private FuncionBloqueoCaida	funcionBloqueoCaida;
	
	static	float[] 			coordenadasZero	= new float[3];

	private float 				mGravedad;
	private float 				mModulo;
	private int 				mEventoBloqueo;
	private float 				mBloqueoT;
	private boolean				mAccionBloqueo;
	private int 				mEventoCaida;
	private float 				mPendienteCaida;
	
	private SobresaltoMediaPlayer sMediaPlayer;

	@Override
	public void onCreate() {
		super.onCreate();
		Log.i("onCreate", "");
		 	    	
		sensorManager = (SensorManager)getSystemService(Context.SENSOR_SERVICE);

		List<Sensor> list;
    	
		//Obtencin del Sensor Acelermetro
		list=sensorManager.getSensorList(Sensor.TYPE_ACCELEROMETER);
		if (list.size()>0) acelerometro=list.get(0);
		
		//Obtencin del Sensor Orientacin
		list=sensorManager.getSensorList(Sensor.TYPE_ORIENTATION);
		if (list.size()>0) orientacion=list.get(0);
		
	    for (int i=0;i<3;i++) {
			coordenadasZero[i]=0;
		}
	}
	public void onStart(Intent intent, int startId) {
		super.onStart(intent, startId);
		
		runningType 	= intent.getBooleanArrayExtra("RUNNING_TYPE");
		runningBloqueo 	= runningType[0];
		runningCaida 	= runningType[1];
 
		if ((runningBloqueo) && (runningCaida)) {
			mGravedad			= intent.getFloatExtra		("BLOQUEO_GRAVEDAD", 	mGravedad);
	        mModulo				= intent.getFloatExtra		("BLOQUEO_MODULO", 		mModulo);
	    	mEventoBloqueo 		= intent.getIntExtra  		("BLOQUEO_EVENTO", 		mEventoBloqueo);
	    	mBloqueoT   		= intent.getFloatExtra		("BLOQUEO_BLOQUEO_T", 	mBloqueoT);
	    	mAccionBloqueo 		= intent.getBooleanExtra	("BLOQUEO_ACCION", 		mAccionBloqueo);
	    	mEventoCaida 		= intent.getIntExtra  		("CAIDA_EVENTO", 		mEventoCaida);
	    	mPendienteCaida		= intent.getFloatExtra		("CAIDA_PENDIENTE",		mPendienteCaida);
	    	funcionBloqueoCaida = new FuncionBloqueoCaida(getBaseContext(), mGravedad, mModulo, mEventoBloqueo, mBloqueoT, mAccionBloqueo, 
														  mEventoCaida, mPendienteCaida);
		} else {
			if (runningBloqueo) {
				mGravedad		= intent.getFloatExtra		("BLOQUEO_GRAVEDAD", 	mGravedad);
		        mModulo			= intent.getFloatExtra		("BLOQUEO_MODULO", 		mModulo);
		    	mEventoBloqueo 	= intent.getIntExtra  		("BLOQUEO_EVENTO", 		mEventoBloqueo);
		    	mBloqueoT   	= intent.getFloatExtra		("BLOQUEO_BLOQUEO_T", 	mBloqueoT);
		    	mAccionBloqueo 	= intent.getBooleanExtra	("BLOQUEO_ACCION", 		mAccionBloqueo);
		    	funcionBloqueoCaida	= new FuncionBloqueoCaida(getBaseContext(), mGravedad, mModulo, mEventoBloqueo, mBloqueoT, mAccionBloqueo);
			}
			if (runningCaida) {
				mEventoCaida 		= intent.getIntExtra  	("CAIDA_EVENTO", 		mEventoCaida);
				mPendienteCaida 	= intent.getFloatExtra	("CAIDA_PENDIENTE", 	mPendienteCaida);
				funcionBloqueoCaida = new FuncionBloqueoCaida(getBaseContext(), mEventoCaida, mPendienteCaida);
			}
		}
		//Registra los escuchadores 
		if ((acelerometro!=null) && (runningBloqueo || runningCaida)) {
			sensorManager.registerListener(this, 
					//acelerometro,SensorManager.SENSOR_DELAY_NORMAL);
					acelerometro,SensorManager.SENSOR_DELAY_FASTEST);
		}
		if ((orientacion!=null) && (runningCaida))					  {
			sensorManager.registerListener(this, 
					//orientacion,SensorManager.SENSOR_DELAY_NORMAL);
					orientacion,SensorManager.SENSOR_DELAY_FASTEST);
		}
	}

	@Override
	public IBinder onBind(Intent arg0) {
		return null;
	}
	
	public	float[] coordenadasAceleracion 	= new float[3];
	public  float[] coordenadasOrientacion 	= new float[3];
	
	private	int		returnBloqueoCaida 	= 0;
		
	@Override
	public void onAccuracyChanged(Sensor sensor, int accuracy) {
	}

	@Override
	public void onSensorChanged(SensorEvent event) {
		
		//implantacin de los escuchadores
    	synchronized (this) {
    		for (int i=0;i<3;i++) {
    			int w=(int)(10*event.values[i]);
    			event.values[i]=(float)(w/10.0f);
    		}
    		//actualizacin de los valores dependiendo del tipo de sensor
	    	if ((event.sensor==acelerometro) && ((runningBloqueo) || (runningCaida)))
	    	{	this.setAcelerometro(event.values);
    			if ((runningBloqueo) && (runningCaida)) {
    				returnBloqueoCaida = funcionBloqueoCaida.tratarACELBloqueoCaida(
    															coordenadasAceleracion[0], 
    						    			  				   	coordenadasAceleracion[1], 
    						    			  				   	coordenadasAceleracion[2],
    						    			  				   	event.timestamp);
    			} else {
	    			if (runningBloqueo) {
	    				returnBloqueoCaida = funcionBloqueoCaida.tratarACELBloqueo(
	    														coordenadasAceleracion[0], 
	    														coordenadasAceleracion[1], 
	    														coordenadasAceleracion[2],
	    														event.timestamp);
	    			}
	    			if (runningCaida) {
	    				returnBloqueoCaida = funcionBloqueoCaida.tratarACELCaida(
	    														coordenadasAceleracion[0], 
	    														coordenadasAceleracion[1], 
	    														coordenadasAceleracion[2],
	    														event.timestamp);
	    			}
    			}
    			switch	(returnBloqueoCaida) {
					case 0 : break;
					case 1 : case 2 : case 3 : case 4 : case 5 :
						if (mAccionBloqueo) {
							sMediaPlayer = new SobresaltoMediaPlayer(this, 5, R.raw.timbre_a1);
							sMediaPlayer.start();
							stopProcesSensors();
							Log.i ("boadcast accion bloqueo", "aa");
							Intent intent = new Intent(Intent.ACTION_VIEW);
							intent.putExtra	("CAIDA", 0);
							intent.putExtra	("BLOQUEO", 1);
							getApplicationContext().sendOrderedBroadcast(intent, null);
						} else {
							sMediaPlayer = new SobresaltoMediaPlayer(this, returnBloqueoCaida, R.raw.timbre_a1);
							sMediaPlayer.start();
						}
						break;
					case 6 :
						sMediaPlayer = new SobresaltoMediaPlayer(this, 5, R.raw.do_3);
						sMediaPlayer.start();	
						break;
					case 99 :
						sMediaPlayer.stop();	
						break;
					case 100:
						sMediaPlayer = new SobresaltoMediaPlayer(this, 5, R.raw.timbre_a1);
						sMediaPlayer.start();
						stopProcesSensors();
						//Log.i ("boadcast Caida", " 100 1");
						Intent intent = new Intent(Intent.ACTION_VIEW);
						intent.putExtra	("CAIDA", 1);
						intent.putExtra	("BLOQUEO", 0);
						getApplicationContext().sendOrderedBroadcast(intent, null);
						//Log.i ("boadcast Caida", " 100 2");
						break;
					default :
						break;
    			}	    			
    		} else {
    			this.setAcelerometro(coordenadasZero);
    		}
/** recordatorio tratamiento sensor orientacin
	    if ((event.sensor==orientacion) && (runningCaida)) 
		    {
    			this.setOrientacion(event.values);
    			ficheroDatos.addDatoORIE(coordenadasOrientacion[0], 
    									 coordenadasOrientacion[1],
/		   	   		 				 	 coordenadasOrientacion[2]);
    		} else {
    			this.setOrientacion(coordenadasZero);
    		}
*/    		
	   	}
	}
	
	public void setAcelerometro (float[] coordenadas) {
		this.coordenadasAceleracion=coordenadas;
		} 

	public void setOrientacion(float[] coordenadas) {
		this.coordenadasOrientacion=coordenadas;
		}
	
	public void stopProcesSensors() {
		// elimina de escucha los sensores
		sensorManager.unregisterListener(this); //sensorEventListener);
		if (runningBloqueo || runningCaida) { acelerometro = null; }
		if (runningCaida) 					{ orientacion  = null; }
	}
	
	public void onDestroy() {
		stopProcesSensors();
		super.onDestroy();
	}
}
